==> PECL_Gen-0.6.1.tgz: PECL_Gen-0.6.1/ExtensionParser.php <==
<?php

	require_once "PECL/Gen/XmlParser.php";
	require_once "PECL/Gen/Maintainer.php";

	/**
	 * Class that parses
	 *
	 * @access public
	 */
	class PECL_Gen_ExtensionParser 
		extends PECL_Gen_XmlParser
  {
		/**
		 * The extension to parse specs into
		 *
		 * @access private
		 * @var    object
		 */
		var $extension;

		/**
		 * A helper stack for collecting stuff 
		 *
		 * @access private
		 * @var    array
		 */
		var $helper_stack = array();

		/**
		 * The current helper (top of stack) 
		 *
		 * @access private
		 * @var    mixed
		 */
		var $helper = false;
		
		/** 
		 * Constructor
		 *
		 * @access public
		 * @param  object the extension to parse specs into
		 */
		function __construct($extension) 
		{
			parent::__construct();
			$this->extension = $extension;
		}

		/**
		 * Push something on the helper stack
		 *
		 * @access private
		 * @param mixed
		 */
		function push_helper($helper)
		{
			array_push($this->helper_stack, $this->helper);
			$this->helper = $helper;
		}


		/**
		 * Pop something from the helper stack
		 *
		 * @access private
		 */
		function pop_helper()
		{
			$this->helper = array_pop($this->helper_stack);
		}

		/**
		 * Trim of leading and trailing whitespace only lines
		 *
		 * @access private
		 * @param  string  text
		 * @return string  trimmed text
		 */
		static function linetrim($text)
		{
			$text = preg_replace('|^\s*\n|m','', $text);
      $text = preg_replace('|\n\s*$|m',"\n", $text);
      return $text;
		}



		function tagend_extension_name($attr, $data)
		{
			return $this->extension->set_name(trim($data));
		}


		function tagend_extension_summary($attr, $data)
		{
			return $this->extension->set_summary(self::linetrim($data));
		}

		function tagend_extension_description($attr, $data)
		{
			return $this->extension->set_description(self::linetrim($data));
		}

		



		function tagstart_maintainer($attr)
		{
			$this->push_helper(new PECL_Gen_Maintainer);
			return true;
		}

		function tagend_maintainer_user($attr, $data)
		{
			return $this->helper->set_user(trim($data));
		}

		function tagend_maintainer_name($attr, $data)
		{
			return $this->helper->set_name(trim($data));
		}

		function tagend_maintainer_email($attr, $data)
		{
			return $this->helper->set_email(trim($data));
		}

		function tagend_maintainer_role($attr, $data)
		{
			return $this->helper->set_role(trim($data));
		}

		function tagend_maintainer($attr, $data)
		{
			$err = $this->extension->add_author($this->helper);
			$this->pop_helper();
			return $err;
		}





		function tagstart_functions_function($attr)
		{
			$this->push_helper(new PECL_Gen_Element_Function);

			if (isset($attr["name"])) {
				$err = $this->helper->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for function missing");
			}

			$role = isset($attr["role"]) ? $attr["role"] : "public";

			$err = $this->helper->set_role($role);
			if (PEAR::isError($err)) {
				return $err;
			}
			
			return true;
		}

		function tagend_function_summary($attr, $data) 
		{
			return $this->helper->set_summary(trim($data));
		}

		function tagend_function_description($attr, $data) 
		{
			return $this->helper->set_description(self::linetrim($data));
		}

		function tagend_function_proto($attr, $data)
		{
			return $this->helper->set_proto(trim($data));
		}

		function tagend_function_code($attr, $data)
		{
			return $this->helper->set_code(self::linetrim($data));
		}

		function tagend_functions_function($attr, $data) 
		{
			$err = $this->extension->add_function($this->helper);
			$this->pop_helper();
			return $err;
		}

		


		function tagstart_resources_resource($attr)
		{
			$this->push_helper(new PECL_Gen_Element_Resource);
			
			if (isset($attr["name"])) {
				$err = $this->helper->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for resource missing");
			}

			if (isset($attr["payload"])) {
				$err = $this->helper->set_payload($attr["payload"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("payload attribut for resource missing");
			}

			if (isset($attr["alloc"])) {
				$err = $this->helper->set_alloc($attr["alloc"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			return true;
		}

		function tagend_resource_destruct($attr, $data)
		{
			return $this->helper->set_destruct(self::linetrim($data));
		}

		function tagend_resource_description($attr, $data)
		{
			return $this->helper->set_description(self::linetrim($data));
		}

		function tagend_resources_resource($attr, $data) 
		{
			$err = $this->extension->add_resource($this->helper);
			$this->pop_helper();
			return $err;
		}



		function tagend_extension_logo($attr, $data)
		{
			// TODO checks
			$logo = new PECL_Gen_Element_Logo($this->extension->name, $attr["src"]);
			return $this->extension->set_logo($logo);
		}



		function tagend_constants_constant($attr, $data)
		{
			$const = new PECL_Gen_Element_Constant;

			if (isset($attr["name"])) {
				$err = $const->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for constant missing");
			}

			if (isset($attr["type"])) {
				$err = $const->set_type($attr["type"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("type attribut for constant missing");
			}

			if (isset($attr["value"])) {
				$err = $const->set_value($attr["value"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 
			
			$const->set_desc(self::linetrim($data));


			return $this->extension->add_constant($const);
		}



		

		function tagend_globals_global($attr, $data)
		{
			$global = new PECL_Gen_Element_Global;

			if (isset($attr["name"])) {
				$err = $global->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for global missing");
			}

			if (isset($attr["type"])) {
				$err = $global->set_type($attr["type"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("type attribut for global missing");
			}

			return $this->extension->add_global($global);
		}

		


		function tagend_globals_phpini($attr, $data)
		{
			$ini = new PECL_Gen_Element_Ini;

			if (isset($attr["name"])) {
				$err = $ini->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for php.ini directive missing");
			}

			if (isset($attr["type"])) {
				$err = $ini->set_type($attr["type"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			if (isset($attr["value"])) {
				$err = $ini->set_value($attr["value"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			if (isset($attr["access"])) {
				$err = $ini->set_access($attr["access"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			if (isset($attr["onupdate"])) {
				$err = $ini->set_onupdate($attr["onupdate"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			$ini->set_desc(self::linetrim($data));

			$err = $this->extension->add_phpini($ini);
			if (PEAR::isError($err)) {
				return $err;
			}
			
			// php.ini settings are stored in modul-global variables
			$global = new PECL_Gen_Element_Global;
			$err = $global->set_name($ini->name);
			if (PEAR::isError($err)) {
				return $err;
			}
			$err = $global->set_type($ini->c_type);
			if (PEAR::isError($err)) {
				return $err;
			}
			
			return $this->extension->add_global($global);
		}

		


		function tagstart_extension_release($attr)
		{
			$this->push_helper(new PECL_Gen_Release);
			return true;
		}

		function tagend_release_version($attr, $data)
		{
			return $this->helper->set_version(trim($data));
		}

		function tagend_release_date($attr, $data)
		{
			return $this->helper->set_date(trim($data));
		}

		function tagend_release_state($attr, $data)
		{
			return $this->helper->set_state(trim($data));
		}

		function tagend_release_notes($attr, $data)
		{
			return $this->helper->set_notes(self::linetrim($data));
		}

		function tagend_extension_release($attr, $data)
		{
			$err = $this->extension->set_release($this->helper);
			$this->pop_helper(new PECL_Gen_Element_Resource);
			return $err;
		}


		
		function tagend_license($attr, $data)
		{
		  $license = PECL_Gen_License::factory(trim($data));

			if (PEAR::isError($license)) {
				return $err;
			}

			return $this->extension->set_license($license);
		}



		function tagstart_extension_deps($attr)
		{
			if (isset($attr["language"])) {
				$err = $this->extension->set_language($attr["language"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			}

			if (isset($attr["platform"])) {
				$err = $this->extension->set_platform($attr["platform"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			}
		}

		function tagstart_deps_lib($attr)
		{
			$this->extension->libs[$attr['name']] = $attr;
			if (isset($attr['platform'])) {
				if ($attr['platform'] != "all") {
					$this->extension->libs[$attr['name']]['platform'] = split("[[:space:]]*,[[:space:]]*", trim($attr['platform']));
				}
			} else {
				$this->extension->libs[$attr['name']]['platform'] = "all";
			}
		}

		function tagstart_deps_header($attr)
		{
			$this->extension->headers[$attr['name']] = $attr; 
		}

		function tagstart_deps_with($attr) {
			$this->extension->with = array();
			$this->extension->with['attr'] = $attr;
			$this->extension->with['desc'] = trim($this->cdata);		
		}

  }

?>

==> PECL_Gen-0.7.0.tgz: PECL_Gen-0.7.0/ExtensionParser.php <==
<?php

	require_once "PECL/Gen/XmlParser.php";
	require_once "PECL/Gen/Maintainer.php";

	/**
	 * Class that parses
	 *
	 * @access public
	 */
	class PECL_Gen_ExtensionParser 
		extends PECL_Gen_XmlParser
  {
		/**
		 * The extension to parse specs into
		 *
		 * @access private
		 * @var    object
		 */
		var $extension;

		/**
		 * A helper stack for collecting stuff 
		 *
		 * @access private
		 * @var    array
		 */
		var $helper_stack = array();

		/**
		 * The current helper (top of stack) 
		 *
		 * @access private
		 * @var    mixed
		 */
		var $helper = false;
		
		/** 
		 * Constructor
		 *
		 * @access public
		 * @param  object the extension to parse specs into
		 */
		function __construct($extension) 
		{
			parent::__construct();
			$this->extension = $extension;
		}

		/**
		 * Push something on the helper stack
		 *
		 * @access private
		 * @param mixed
		 */
		function push_helper($helper)
		{
			array_push($this->helper_stack, $this->helper);
			$this->helper = $helper;
		}


		/**
		 * Pop something from the helper stack
		 *
		 * @access private
		 */
		function pop_helper()
		{
			$this->helper = array_pop($this->helper_stack);
		}

		/**
		 * Trim of leading and trailing whitespace only lines
		 *
		 * @access private
		 * @param  string  text
		 * @return string  trimmed text
		 */
		static function linetrim($text)
		{
			$text = preg_replace('|^\s*\n|m','', $text);
      $text = preg_replace('|\n\s*$|m',"\n", $text);
      return $text;
		}



		function tagend_extension_name($attr, $data)
		{
			return $this->extension->set_name(trim($data));
		}


		function tagend_extension_summary($attr, $data)
		{
			return $this->extension->set_summary(self::linetrim($data));
		}

		function tagend_extension_description($attr, $data)
		{
			return $this->extension->set_description(self::linetrim($data));
		}

		



		function tagstart_maintainer($attr)
		{
			$this->push_helper(new PECL_Gen_Maintainer);
			return true;
		}

		function tagend_maintainer_user($attr, $data)
		{
			return $this->helper->set_user(trim($data));
		}

		function tagend_maintainer_name($attr, $data)
		{
			return $this->helper->set_name(trim($data));
		}

		function tagend_maintainer_email($attr, $data)
		{
			return $this->helper->set_email(trim($data));
		}

		function tagend_maintainer_role($attr, $data)
		{
			return $this->helper->set_role(trim($data));
		}

		function tagend_maintainer($attr, $data)
		{
			$err = $this->extension->add_author($this->helper);
			$this->pop_helper();
			return $err;
		}





		function tagstart_functions_function($attr)
		{
			$this->push_helper(new PECL_Gen_Element_Function);

			if (isset($attr["name"])) {
				$err = $this->helper->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for function missing");
			}

			$role = isset($attr["role"]) ? $attr["role"] : "public";

			$err = $this->helper->set_role($role);
			if (PEAR::isError($err)) {
				return $err;
			}
			
			return true;
		}

		function tagend_function_summary($attr, $data) 
		{
			return $this->helper->set_summary(trim($data));
		}

		function tagend_function_description($attr, $data) 
		{
			return $this->helper->set_description(self::linetrim($data));
		}

		function tagend_function_proto($attr, $data)
		{
			return $this->helper->set_proto(trim($data));
		}

		function tagend_function_code($attr, $data)
		{
			return $this->helper->set_code(self::linetrim($data));
		}

		function tagend_functions_function($attr, $data) 
		{
			$err = $this->extension->add_function($this->helper);
			$this->pop_helper();
			return $err;
		}

		


		function tagstart_resources_resource($attr)
		{
			$this->push_helper(new PECL_Gen_Element_Resource);
			
			if (isset($attr["name"])) {
				$err = $this->helper->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for resource missing");
			}

			if (isset($attr["payload"])) {
				$err = $this->helper->set_payload($attr["payload"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("payload attribut for resource missing");
			}

			if (isset($attr["alloc"])) {
				$err = $this->helper->set_alloc($attr["alloc"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			return true;
		}

		function tagend_resource_destruct($attr, $data)
		{
			return $this->helper->set_destruct(self::linetrim($data));
		}

		function tagend_resource_description($attr, $data)
		{
			return $this->helper->set_description(self::linetrim($data));
		}

		function tagend_resources_resource($attr, $data) 
		{
			$err = $this->extension->add_resource($this->helper);
			$this->pop_helper();
			return $err;
		}



		function tagend_extension_logo($attr, $data)
		{
			// TODO checks
			$logo = new PECL_Gen_Element_Logo($this->extension->name, $attr["src"]);
			return $this->extension->set_logo($logo);
		}



		function tagend_constants_constant($attr, $data)
		{
			$const = new PECL_Gen_Element_Constant;

			if (isset($attr["name"])) {
				$err = $const->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for constant missing");
			}

			if (isset($attr["type"])) {
				$err = $const->set_type($attr["type"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("type attribut for constant missing");
			}

			if (isset($attr["value"])) {
				$err = $const->set_value($attr["value"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 
			
			$const->set_desc(self::linetrim($data));


			return $this->extension->add_constant($const);
		}



		

		function tagend_globals_global($attr, $data)
		{
			$global = new PECL_Gen_Element_Global;

			if (isset($attr["name"])) {
				$err = $global->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for global missing");
			}

			if (isset($attr["type"])) {
				$err = $global->set_type($attr["type"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("type attribut for global missing");
			}

			return $this->extension->add_global($global);
		}

		


		function tagend_globals_phpini($attr, $data)
		{
			$ini = new PECL_Gen_Element_Ini;

			if (isset($attr["name"])) {
				$err = $ini->set_name($attr["name"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} else {
				return $this->raiseError("name attribut for php.ini directive missing");
			}

			if (isset($attr["type"])) {
				$err = $ini->set_type($attr["type"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			if (isset($attr["value"])) {
				$err = $ini->set_value($attr["value"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			if (isset($attr["access"])) {
				$err = $ini->set_access($attr["access"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			if (isset($attr["onupdate"])) {
				$err = $ini->set_onupdate($attr["onupdate"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			} 

			$ini->set_desc(self::linetrim($data));

			$err = $this->extension->add_phpini($ini);
			if (PEAR::isError($err)) {
				return $err;
			}
			
			// php.ini settings are stored in modul-global variables
			$global = new PECL_Gen_Element_Global;
			$err = $global->set_name($ini->name);
			if (PEAR::isError($err)) {
				return $err;
			}
			$err = $global->set_type($ini->c_type);
			if (PEAR::isError($err)) {
				return $err;
			}
			
			return $this->extension->add_global($global);
		}

		


		function tagstart_extension_release($attr)
		{
			$this->push_helper(new PECL_Gen_Release);
			return true;
		}

		function tagend_release_version($attr, $data)
		{
			return $this->helper->set_version(trim($data));
		}

		function tagend_release_date($attr, $data)
		{
			return $this->helper->set_date(trim($data));
		}

		function tagend_release_state($attr, $data)
		{
			return $this->helper->set_state(trim($data));
		}

		function tagend_release_notes($attr, $data)
		{
			return $this->helper->set_notes(self::linetrim($data));
		}

		function tagend_extension_release($attr, $data)
		{
			$err = $this->extension->set_release($this->helper);
			$this->pop_helper(new PECL_Gen_Element_Resource);
			return $err;
		}


		
		function tagend_license($attr, $data)
		{
		  $license = PECL_Gen_License::factory(trim($data));

			if (PEAR::isError($license)) {
				return $err;
			}

			return $this->extension->set_license($license);
		}



		function tagstart_extension_deps($attr)
		{
			if (isset($attr["language"])) {
				$err = $this->extension->set_language($attr["language"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			}

			if (isset($attr["platform"])) {
				$err = $this->extension->set_platform($attr["platform"]);
				if (PEAR::isError($err)) {
					return $err;
				}
			}
		}

		function tagstart_deps_lib($attr)
		{
			$this->extension->libs[$attr['name']] = $attr;
			if (isset($attr['platform'])) {
				$platform = new PECL_Gen_Tools_Platform($attr["platform"]);
			} else {
				$platform = new PECL_Gen_Tools_Platform("all");
			}

			if (PEAR::isError($platform)) {
				return $platform;
			}

			$this->extension->libs[$attr['name']]['platform'] = $platform;
			return true;
		}

		function tagstart_deps_header($attr)
		{
			$this->extension->headers[$attr['name']] = $attr; 
		}

		function tagend_deps_with($attr, $data) {
			$this->extension->with = array();
			$this->extension->with['attr'] = $attr;
			$this->extension->with['desc'] = trim($data);		
		}


		function tagend_extension_code($attr, $data) {
			$this->extension->add_code($attr["role"], self::linetrim($data));
		}

  }

?>
